From 7a175d049f2de72795b7d81baa4d41f59b3b7ef1 Mon Sep 17 00:00:00 2001
From: liuyg <376836862@qq.com>
Date: Fri, 13 Aug 2021 20:48:28 +0800
Subject: [PATCH] 保安公司修改  字段, 加处罚,资格审查调整  搜索 字段  成绩查询  保安服务单位   报名列表

---
 src/views/qualificationExamination/qualificationExamination.vue |   66 ++++++++++++++++++++++++++++----
 1 files changed, 57 insertions(+), 9 deletions(-)

diff --git a/src/views/qualificationExamination/qualificationExamination.vue b/src/views/qualificationExamination/qualificationExamination.vue
index 741e17e..34cce98 100644
--- a/src/views/qualificationExamination/qualificationExamination.vue
+++ b/src/views/qualificationExamination/qualificationExamination.vue
@@ -79,6 +79,7 @@
           {
             label: "保安公司",
             prop: "deptName",
+            minWidth: 110,
             overHidden: true,
             // labelWidth: 120,
             // searchLabelWidth: 120,
@@ -138,6 +139,7 @@
           {
             label: "性别",
             prop: "sexName",
+            width: 56,
             // type: "select",
             // labelWidth: 120,
             // // display: false,
@@ -153,6 +155,7 @@
           {
             label: "身份证号",
             prop: "cardid",
+            width: 139,
             // type: "select",
             // labelWidth: 120,
             // // display: false,
@@ -161,8 +164,9 @@
             // //   label: "label",
             // //   value: "value",
             // // },
-            // searchSpan: 5,
-            // search: true,
+            searchSpan: 4,
+            search: true,
+
             // width: 120,
           },
           // {
@@ -171,6 +175,30 @@
           //   // labelWidth: 120,
           //   // display: false,
           // },
+          {
+            label: "年龄",
+            prop: "age",
+            // display: false,
+            // labelWidth: 120,
+            // width: 200,
+          },
+          {
+            label: "出生日期",
+            prop: "birthday",
+            type: "date",
+            format: "yyyy-MM-dd",
+            valueFormat: "yyyy-MM-dd",
+            // display: false,
+            // labelWidth: 120,
+            // width: 200,
+          },
+          {
+            label: "保安员证编号",
+            prop: "securitynumber",
+            searchLabelWidth: 110,
+            searchSpan: 4,
+            search: true,
+          },
           {
             label: "联系方式",
             prop: "phone",
@@ -224,12 +252,12 @@
             // display: false,
             hide: true,
           },
-          {
-            label: "是否在职",
-            prop: "onjob",
-            // labelWidth: 120,
-            // display: false,
-          },
+          // {
+          //   label: "是否在职",
+          //   prop: "status",
+          //   // labelWidth: 120,
+          //   // display: false,
+          // },
         ],
         // group: [
         //   {
@@ -373,9 +401,14 @@
     refreshChange() {
       this.onLoad(this.page, this.query);
     },
+    getyears() {
+      var d = new Date();
+      return d.getFullYear();
+    },
     onLoad(page, params = {}) {
       // this.loading = false;
       this.loading = true;
+      params["status"] = 1;
       getListSecurity(
         page.currentPage,
         page.pageSize,
@@ -383,7 +416,22 @@
       ).then((res) => {
         const data = res.data.data;
         this.page.total = data.total;
-        this.data = data.records;
+        var d = data.records;
+        for (var k in d) {
+          if (d[k]["examinationMx"] == "") {
+            d[k]["examinationMx"] = "正常";
+            d[k]["examinationType"] = "正常";
+          } else {
+            d[k]["examinationType"] = "异常";
+          }
+          // if (d[k]["examinationType"] == "") {
+          //   d[k]["examinationType"] = "正常";
+          // }
+          var sfz = d[k].cardid.substring(6, 10);
+          d[k]["age"] = this.getyears() - sfz;
+        }
+        this.data = d;
+        // this.data = data.records;
         console.log(this.data);
         this.loading = false;
         // this.selectionClear();

--
Gitblit v1.9.3